package com.example.tomatoandpotatoapp.Screens

import android.app.LoaderManager.LoaderCallbacks
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Card
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.material3.contentColorFor
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Brush
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.ImageBitmap
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.imageResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.compose.ui.util.fastCbrt
import androidx.navigation.NavController
import com.example.tomatoandpotatoapp.ViewModelsPack.SupabaseAuthViewModel
import androidx.lifecycle.viewmodel.compose.viewModel
import coil.compose.AsyncImagePainter
import coil.compose.rememberAsyncImagePainter
import coil.request.ImageRequest
import com.example.tomatoandpotatoapp.R
import com.example.tomatoandpotatoapp.navigationPack.Screens
import com.example.tomatoandpotatoapp.utils.EditProfileString
import io.github.jan.supabase.realtime.Column
import io.ktor.http.ContentType
import org.w3c.dom.Text


@Composable
fun ShowPlants(
    viewModel: SupabaseAuthViewModel = viewModel(),
    navController: NavController,
) {
    val plants = viewModel.plants

    val flag = remember { mutableStateOf(true) }
    if (flag.value) {
        viewModel.alonePlant
        flag.value = false
    }
    Box(modifier = Modifier.fillMaxSize()) {
        Box(
            modifier = Modifier
                .fillMaxSize()
                .background(
                    brush = Brush.verticalGradient(
                        colors = listOf(
                            Color(0xFF666666).copy(alpha = 0.85f),
                            Color(0xFF666666).copy(alpha = 0.1f)
                        ),
                        startY = 0.0f,
                        endY = 1500.0f
                    )
                )
        )
        Column(
            modifier = Modifier.fillMaxSize()
        ) {
            Row(
                modifier = Modifier
                    .fillMaxWidth()
                    .height(105.dp)
                    .background(color = Color(0xffD9D9D9)),
                horizontalArrangement = Arrangement.Center,
                verticalAlignment = Alignment.CenterVertically
            ) {
                Column(
                    modifier = Modifier
                        .fillMaxHeight(), verticalArrangement = Arrangement.Center
                ) {
                    Text(
                        text = "Каталог",
                        fontWeight = FontWeight.W800,
                        color = Color.Black,
                        fontSize = 25.sp
                    )
                    //ПОИСК ПО КАТАЛОГУ

                }
            }

            Spacer(modifier = Modifier.height(60.dp))

            if (plants.value.isNotEmpty()) {
                LazyColumn() {
                    items(plants.value) { plants ->
                        val image = rememberAsyncImagePainter(
                            model = ImageRequest.Builder(
                                LocalContext.current
                            ).data(plants.image)
                                .size(200, 200).build()
                        ).state
                        Card(
                            modifier = Modifier
                                .fillMaxWidth()
                                .padding(20.dp)
                                .height(350.dp)
                        ) {
                            Column(
                                Modifier.fillMaxSize(),
                                horizontalAlignment = Alignment.CenterHorizontally,
                                verticalArrangement = Arrangement.Center
                            ) {
                                if (image is AsyncImagePainter.State.Success) {
                                    Box(
                                        modifier = Modifier
                                            .fillMaxWidth()
                                            .height(250.dp)
                                    ) {
                                        Image(
                                            painter = image.painter,
                                            contentDescription = "",
                                            contentScale = ContentScale.Crop,
                                            modifier = Modifier
                                                .fillMaxWidth()
                                                .height(200.dp),
                                        )

                                    }
                                }
                                if (image is AsyncImagePainter.State.Loading) {
                                    Box(
                                        modifier = Modifier
                                            .fillMaxWidth()
                                            .height(250.dp),
                                        contentAlignment = Alignment.Center
                                    ) {
                                        CircularProgressIndicator()
                                    }

                                }
                                Text(plants.title, fontSize = 20.sp, fontWeight = FontWeight.Black)
                                if (!plants.description.isNullOrEmpty()) {
                                    Text(plants.description, fontSize = 14.sp)
                                }
                            }
                        }
                    }
                }
            }
            Spacer(modifier = Modifier.weight(0.2f))

            Row(
                modifier = Modifier
                    .fillMaxWidth()
                    .height(105.dp)
                    .align(Alignment.End)
                    .background(color = Color(0xff718588)),
                horizontalArrangement = Arrangement.SpaceEvenly
            ) {
                IconButton(
                    onClick = { },
                    modifier = Modifier.size(120.dp)
                ) {
                    Icon(
                        bitmap = ImageBitmap.imageResource(R.drawable.message),
                        contentDescription = "",
                        modifier = Modifier.size(55.dp)
                    )
                }
                IconButton(
                    onClick = { /*TODO*/ },
                    modifier = Modifier.size(120.dp)
                ) {
                    Icon(
                        bitmap = ImageBitmap.imageResource(R.drawable.catalogblack),
                        contentDescription = "",
                        modifier = Modifier.size(55.dp)
                    )
                }
                IconButton(
                    onClick = { navController.navigate(Screens.ProfileScreen.route) },
                    modifier = Modifier.size(120.dp)
                ) {
                    Icon(
                        bitmap = ImageBitmap.imageResource(R.drawable.profile),
                        contentDescription = "",
                        modifier = Modifier.size(55.dp)
                    )
                }

            }
        }


    }

}