package com.example.tomatoandpotatoapp.Screens

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.focusable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.KeyboardArrowLeft
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.focus.focusModifier
import androidx.compose.ui.graphics.Brush
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.ImageBitmap
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.imageResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.lifecycle.viewmodel.compose.viewModel
import coil.compose.AsyncImagePainter
import coil.compose.rememberAsyncImagePainter
import coil.request.ImageRequest
import com.example.tomatoandpotatoapp.R
import com.example.tomatoandpotatoapp.ViewModelsPack.SupabaseAuthViewModel
import com.example.tomatoandpotatoapp.navigationPack.Screens


@Preview
@Composable
fun CurrentPlant(viewModel: SupabaseAuthViewModel = viewModel()) {

    val alonePlant = viewModel.alonePlant
    val plants = viewModel.plants


    Box(modifier = Modifier.fillMaxSize()) {
        Box(
            modifier = Modifier
                .fillMaxSize()
                .background(
                    brush = Brush.verticalGradient(
                        colors = listOf(
                            Color(0xFF666666).copy(alpha = 0.85f),
                            Color(0xFF666666).copy(alpha = 0.1f)
                        ),
                        startY = 0.0f,
                        endY = 1500.0f
                    )
                )
        )
        Column(modifier = Modifier.fillMaxSize()) {
            Row(
                modifier = Modifier
                    .fillMaxWidth()
                    .height(95.dp)
                    .background(color = Color(0xffD9D9D9)),


                ) {
                Column(
                    horizontalAlignment = Alignment.CenterHorizontally,
                    verticalArrangement = Arrangement.Center
                ) {
                    Button(
                        onClick = {
                            //navController.navigate(Screens.PlantsCatalog.route)
                        },
                        modifier = Modifier
                            .padding(start = 28.dp, top = 41.dp)
                            .width(31.dp)
                            .height(31.dp),
                        colors = ButtonDefaults.buttonColors(containerColor = Color(0xFF78EE99)),
                        shape = RoundedCornerShape(10.dp),
                        contentPadding = PaddingValues(1.dp)
                    ) {
                        Icon(
                            imageVector = Icons.Filled.KeyboardArrowLeft,
                            contentDescription = ""
                        )
                    }
                }

                Column(
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(top = 42.dp, end = 36.dp),
                    horizontalAlignment = Alignment.CenterHorizontally,
                    verticalArrangement = Arrangement.Center
                ) {
                    Text(
                        text = "alonePlant!!.title",
                        fontSize = 25.sp,
                        fontWeight = FontWeight.W700,
                        textAlign = TextAlign.Center
                    )
                    //cry(((

                }
            }

            Spacer(modifier = Modifier.height(60.dp))

            if (plants.value.isNotEmpty()) {
                LazyColumn() {
                    items(plants.value) { plants ->
                        val image = rememberAsyncImagePainter(
                            model = ImageRequest.Builder(
                                LocalContext.current
                            ).data(plants.image).size(200, 200).build()
                        ).state
                        Column {
                            if (image is AsyncImagePainter.State.Success) {
                                Box(
                                    modifier = Modifier
                                        .width(200.dp)
                                        .height(200.dp),
                                    contentAlignment = Alignment.Center
                                ) {
                                    Image(
                                        modifier = Modifier
                                            .fillMaxWidth()
                                            .height(200.dp),
                                        painter = image.painter,
                                        contentDescription = "",
                                        contentScale = ContentScale.Crop
                                    )
                                }
                            }
                            if (image is AsyncImagePainter.State.Loading) {
                                Box(
                                    modifier = Modifier
                                        .fillMaxWidth()
                                        .height(250.dp),
                                    contentAlignment = Alignment.Center
                                ) {
                                    CircularProgressIndicator()
                                }
                            }

                            Text(
                                plants.description,
                                fontSize = 20.sp,
                                fontWeight = FontWeight.Black
                            )
                            Text(
                                plants.growingSteps,
                                fontSize = 20.sp,
                                fontWeight = FontWeight.Black
                            )
                            Text(
                                plants.recommendation,
                                fontSize = 20.sp,
                                fontWeight = FontWeight.Black
                            )
                        }

                    }
                }
                Spacer(modifier = Modifier.weight(0.2f))

                Row(
                    modifier = Modifier
                        .fillMaxWidth()
                        .height(105.dp)
                        .background(color = Color(0xff718588)),
                    horizontalArrangement = Arrangement.SpaceEvenly
                ) {
                    IconButton(
                        onClick = { },
                        modifier = Modifier.size(120.dp)
                    ) {
                        Icon(
                            bitmap = ImageBitmap.imageResource(R.drawable.message),
                            contentDescription = "",
                            modifier = Modifier.size(55.dp)
                        )
                    }
                    IconButton(
                        onClick = { /*TODO*/ },
                        modifier = Modifier.size(120.dp)
                    ) {
                        Icon(
                            bitmap = ImageBitmap.imageResource(R.drawable.catalogblack),
                            contentDescription = "",
                            modifier = Modifier.size(55.dp)
                        )
                    }
                    IconButton(
                        onClick = { /*navController.navigate(Screens.ProfileScreen.route)*/ },
                        modifier = Modifier.size(120.dp)
                    ) {
                        Icon(
                            bitmap = ImageBitmap.imageResource(R.drawable.profile),
                            contentDescription = "",
                            modifier = Modifier.size(55.dp)
                        )
                    }


                }
            }
        }
    }
}